@@ -16,7 +16,7 @@ from .event_id import EventID
 from .exceptions import custom_error_handler
 from .utils.file_download import _download_files, _save_file_map_fn, _get_file_map_fn
 from .utils.file_upload import check_file
-from .settings import GWCLOUD_ENDPOINT, GWCLOUD_AUTH_ENDPOINT
+from .settings import GWCLOUD_ENDPOINT
 
 logger = create_logger(__name__)
 
@@ -29,8 +29,6 @@ class GWCloud:
     ----------
     token : str, optional
         API token for a Bilby user. If omitted, creates an anonymous read-only GWCloud instance
-    auth_endpoint : str, optional
-        URL to which we send the authentication queries, by default GWCLOUD_AUTH_ENDPOINT
     endpoint : str, optional
         URL to which we send the queries, by default GWCLOUD_ENDPOINT
 
@@ -39,12 +37,12 @@ class GWCloud:
     client : GWDC
         Handles a lot of the underlying logic surrounding the queries
     """
-    def __init__(self, token="", auth_endpoint=GWCLOUD_AUTH_ENDPOINT, endpoint=GWCLOUD_ENDPOINT):
+
+    def __init__(self, token="", endpoint=GWCLOUD_ENDPOINT):
         self.client = GWDC(
             token=token,
-            auth_endpoint=auth_endpoint,
             endpoint=endpoint,
-            custom_error_handler=custom_error_handler
+            custom_error_handler=custom_error_handler,
         )
         self.request = self.client.request  # Setting shorthand for simplicity
 
@@ -188,8 +186,9 @@ class GWCloud:
         finally:
             os.chdir(str(cwd))
 
-    def get_preferred_job_list(self, search=""):
-        """Get list of public Bilby jobs corresponding to a search of "preferred" and a time_range of "Any time"
+    def get_official_job_list(self, search=""):
+        """Get list of public Bilby jobs corresponding to a search of "labels.name:Official" and
+        a time_range of "Any time"
 
         Parameters
         ----------
@@ -199,13 +198,14 @@ class GWCloud:
         Returns
         -------
         list
-            List of BilbyJob instances for the preferred jobs corresponding to the search terms
+            List of BilbyJob instances for the official jobs corresponding to the search terms
         """
-        return self.get_public_job_list(search=f"preferred lasky {search}", time_range=TimeRange.ANY)
+        return self.get_public_job_list(search=f"labels.name:Official {search}", time_range=TimeRange.ANY)
 
     def _get_job_model_from_query(self, query_data):
         if not query_data:
             return None
+
         return BilbyJob(
             client=self,
             **rename_dict_keys(
@@ -364,7 +364,7 @@ class GWCloud:
 
         return [self._get_job_model_from_query(job['node']) for job in data['bilby_jobs']['edges']]
 
-    def _get_files_by_job_id(self, job_id):
+    def _get_files_by_bilby_job(self, job):
         query = """
             query ($jobId: ID!) {
                 bilbyResultFiles (jobId: $jobId) {
@@ -374,17 +374,17 @@ class GWCloud:
                         fileSize
                         downloadToken
                     }
-                    isUploadedJob
+                    jobType
                 }
             }
         """
 
         variables = {
-            "jobId": job_id
+            "jobId": job.id
         }
 
         data = self.request(query=query, variables=variables)
-        uploaded = data['bilby_result_files']['is_uploaded_job']
+        job.type = data['bilby_result_files']['job_type']
 
         file_list = FileReferenceList()
         for file_data in data['bilby_result_files']['files']:
@@ -394,12 +394,10 @@ class GWCloud:
             file_list.append(
                 FileReference(
                     **file_data,
-                    job_id=job_id,
-                    uploaded=uploaded
+                    parent=job
                 )
             )
-
-        return file_list, uploaded
+        return file_list
 
     def get_files_by_reference(self, file_references):
         """Obtains file data when provided a :class:`~gwdc_python.files.file_reference.FileReferenceList`
@@ -425,17 +423,14 @@ class GWCloud:
         file_ids = list(itertools.chain.from_iterable(file_ids))
         batched_files = FileReferenceList(list(itertools.chain.from_iterable(batched.values())))
 
-        file_paths = batched_files.get_paths()
-        file_uploaded = batched_files.get_uploaded()
-        total_size = batched_files.get_total_bytes()
-
-        files = _download_files(_get_file_map_fn, file_ids, file_paths, file_uploaded, total_size)
+        files = _download_files(_get_file_map_fn, file_ids, batched_files)
+        file_dict = {key: val for key, val in files}
 
         logger.info(f'All {len(file_ids)} files downloaded!')
 
-        return files
+        return [(ref.path, file_dict[ref.path]) for ref in file_references]
 
-    def save_files_by_reference(self, file_references, root_path, preserve_directory_structure=True):
+    def save_files_by_reference(self, file_references, root_path):
         """Save files when provided a :class:`~gwdc_python.files.file_reference.FileReferenceList` and a root path
 
         Parameters
@@ -445,8 +440,6 @@ class GWCloud:
             to save the associated files
         root_path : str or ~pathlib.Path
             Directory into which to save the files
-        preserve_directory_structure : bool, optional
-            Remove any directory structure for the downloaded files, by default True
         """
         batched = file_references.batched
 
@@ -458,11 +451,7 @@ class GWCloud:
         file_ids = list(itertools.chain.from_iterable(file_ids))
         batched_files = FileReferenceList(list(itertools.chain.from_iterable(batched.values())))
 
-        file_paths = batched_files.get_output_paths(root_path, preserve_directory_structure)
-        file_uploaded = batched_files.get_uploaded()
-        total_size = batched_files.get_total_bytes()
-
-        _download_files(_save_file_map_fn, file_ids, file_paths, file_uploaded, total_size)
+        _download_files(_save_file_map_fn, file_ids, batched_files, root_path)
 
         logger.info(f'All {len(file_ids)} files saved!')
 
@@ -609,12 +598,60 @@ class GWCloud:
         with NamedTemporaryFile(dir=job_directory, suffix='.tar.gz') as f:
             with tarfile.open(f.name, "w:gz", compresslevel=2) as tar_handle:
                 for item in path.rglob("*"):
-                    print(item)
                     tar_handle.add(item, arcname=item.relative_to(path), recursive=False)
 
             # Upload the archive
             return self.upload_job_archive(description, f.name, public)
 
+    def upload_external_job(self, job_name, job_description, private, ini_string, url):
+        """Upload a Bilby job to GWCloud with external results
+
+        Parameters
+        ----------
+        job_name : str
+            Name of the job to be created
+        job_description : str
+            Description of the job to be created
+        private : bool
+            True if job should be private, False if public
+        ini_string : str
+            The contents of a Bilby ini file
+        url : str
+            The URL to the external results. Might be a url directly to a result file, or to a directory listing, or
+            something else
+
+        Returns
+        -------
+        BilbyJob
+            The created Bilby job
+        """
+        query = """
+            mutation UploadExternalBilbyJob($input: UploadExternalBilbyJobMutationInput!) {
+                uploadExternalBilbyJob(input: $input) {
+                    result {
+                        jobId
+                    }
+                }
+            }
+        """
+
+        variables = {
+            "input": {
+                "details": {
+                    "name": job_name,
+                    "description": job_description,
+                    "private": private
+                },
+                "iniFile": ini_string,
+                "resultUrl": url
+            }
+        }
+
+        data = self.request(query=query, variables=variables)
+
+        job_id = data['upload_external_bilby_job']['result']['job_id']
+        return self.get_job_by_id(job_id)
+
     def create_event_id(self, event_id, gps_time, trigger_id=None, nickname=None, is_ligo_event=False):
         """Create an Event ID that can be assigned to Bilby Jobs
 
